@@ -63,6 +63,15 @@ pub(crate) const SYS_futex: c_long = 98;
 #[cfg(target_arch = "arm")]
 pub(crate) const SYS_futex: c_long = 240;
 
+#[cfg(any(
+    target_arch = "x86_64",
+    target_arch = "x86",
+    target_arch = "aarch64",
+    target_arch = "riscv64",
+    target_arch = "arm"
+))]
+pub(crate) const SYS_clone3: c_long = 435;
+
 pub(crate) const CLOCK_REALTIME: c_int = 0;
 pub(crate) const CLOCK_MONOTONIC: c_int = 1;
 
@@ -276,7 +285,7 @@ pub(crate) struct Addrinfo {
     pub(crate) ai_socktype: c_int,
     pub(crate) ai_protocol: c_int,
     pub(crate) ai_addrlen: SockLen,
-    pub(crate) ai_addr: *mut rsix::net::SocketAddrStorage,
+    pub(crate) ai_addr: *mut rustix::net::SocketAddrStorage,
     pub(crate) ai_canonname: *mut i8,
     pub(crate) ai_next: *mut Addrinfo,
 }
@@ -414,3 +423,10 @@ pub(crate) struct Elf_Phdr {
     pub(crate) p_memsz: u64,
     pub(crate) p_align: u64,
 }
+
+pub struct CpuSet {
+    #[cfg(all(target_pointer_width = "32", not(target_arch = "x86_64")))]
+    pub(crate) bits: [u32; 32],
+    #[cfg(not(all(target_pointer_width = "32", not(target_arch = "x86_64"))))]
+    pub(crate) bits: [u64; 16],
+}
